@@ -1,3 +1,4 @@
+// clang-format off
 /*
   class CvsIgnoreList from Cervisia cvsdir.cpp
      SPDX-FileCopyrightText: 1999-2002 Bernd Gehrmann <bernd at mail.berlios.de>
@@ -9,6 +10,7 @@
   SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
   SPDX-License-Identifier: GPL-2.0-or-later
  */
+// clang-format on
 #include "CvsIgnoreList.h"
 
 #include "fileaccess.h"        // for FileAccess
@@ -69,7 +71,7 @@ void CvsIgnoreList::addEntriesFromString(const QString& dir, const QString& str)
     We don't have a real file in AUTOTEST mode
 */
 void CvsIgnoreList::addEntriesFromFile(const QString& dir, const QString& name)
-{
+{ //want unused warning when not building autotest
 #ifdef AUTOTEST
     Q_UNUSED(name);
     Q_UNUSED(dir);
