@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -7,6 +8,7 @@
 // clang-format on
 
 #ifndef FILENAMELINEEDIT_H
+#define FILENAMELINEEDIT_H
 
 #include <QLineEdit>
 
