@@ -1,4 +1,4 @@
-
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -6,6 +6,7 @@
  * SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
+// clang-format on
 
 #include "ProgressProxy.h"
 
@@ -17,7 +18,11 @@
 #include <QString>
 
 namespace signals2 = boost::signals2;
-
+/*
+    Using boost allows ProgessProxy to be disconnected during auto testing.
+    This prevents uneeded UI calls from being made in an evironment were they
+    cann't function properly.
+*/
 signals2::signal<void()> ProgressProxy::startBackgroundTask;
 signals2::signal<void()> ProgressProxy::endBackgroundTask;
 
@@ -28,9 +33,9 @@ signals2::signal<void()> ProgressProxy::clear;
 signals2::signal<void(KJob*, const QString&)> ProgressProxy::enterEventLoop;
 signals2::signal<void()> ProgressProxy::exitEventLoop;
 
-signals2::signal<void(qint64, bool)> ProgressProxy::setCurrentSig;
-signals2::signal<void(qint64)> ProgressProxy::setMaxNofSteps;
-signals2::signal<void(qint64)> ProgressProxy::addNofSteps;
+signals2::signal<void(quint64, bool)> ProgressProxy::setCurrentSig;
+signals2::signal<void(quint64)> ProgressProxy::setMaxNofSteps;
+signals2::signal<void(quint64)> ProgressProxy::addNofSteps;
 signals2::signal<void(bool)> ProgressProxy::stepSig;
 
 signals2::signal<void(double, double)> ProgressProxy::setRangeTransformation;
@@ -61,7 +66,7 @@ void ProgressProxy::setInformation(const QString& info, qint32 current, bool bRe
     setInformationSig(info, bRedrawUpdate);
 }
 
-void ProgressProxy::setCurrent(qint64 current, bool bRedrawUpdate)
+void ProgressProxy::setCurrent(quint64 current, bool bRedrawUpdate)
 {
     setCurrentSig(current, bRedrawUpdate);
 }
