@@ -1,3 +1,12 @@
+// clang-format off
+/*
+ * KDiff3 - Text Diff And Merge Tool
+ *
+ * SPDX-FileCopyrightText: 2002-2011 Joachim Eibl, joachim.eibl at gmx.de
+ * SPDX-FileCopyrightText: 2018-2020 Michael Reeves reeves.87@gmail.com
+ * SPDX-License-Identifier: GPL-2.0-or-later
+ */
+// clang-format on
 
 #ifndef PROGRESSPROXY_H
 #define PROGRESSPROXY_H
@@ -27,7 +36,7 @@ class ProgressProxy
   public:
     static void setInformation(const QString& info, bool bRedrawUpdate = true);
     static void setInformation(const QString& info, qint32 current, bool bRedrawUpdate = true);
-    static void setCurrent(qint64 current, bool bRedrawUpdate = true);
+    static void setCurrent(quint64 current, bool bRedrawUpdate = true);
     static void step(bool bRedrawUpdate = true);
 
     static signals2::signal<void()> startBackgroundTask;
@@ -40,9 +49,9 @@ class ProgressProxy
     static signals2::signal<void(KJob*, const QString&)> enterEventLoop;
     static signals2::signal<void()> exitEventLoop;
 
-    static signals2::signal<void(qint64, bool)> setCurrentSig;
-    static signals2::signal<void(qint64)> setMaxNofSteps;
-    static signals2::signal<void(qint64)> addNofSteps;
+    static signals2::signal<void(quint64, bool)> setCurrentSig;
+    static signals2::signal<void(quint64)> setMaxNofSteps;
+    static signals2::signal<void(quint64)> addNofSteps;
     static signals2::signal<void(bool)> stepSig;
 
     static signals2::signal<void(double, double)> setRangeTransformation;
