@@ -11,13 +11,15 @@
 #ifndef RLPAINTER_H
 #define RLPAINTER_H
 
+#include "TypeUtils.h"
+
 #include <QPainter>
 // Helper class that swaps left and right for some commands.
 
 /*
     This class assists with changing KDiff3 between RTL and LTR layout.
 */
-class RLPainter : public QPainter
+class RLPainter: public QPainter
 {
   private:
     qint32 m_xOffset;
@@ -25,8 +27,8 @@ class RLPainter : public QPainter
     bool bRightToLeft = false;
 
   public:
-    RLPainter(QPaintDevice* pd, bool bRTL, qint32 width, qint32 fontWidth)
-        : QPainter(pd)
+    RLPainter(QPaintDevice* pd, bool bRTL, qint32 width, qint32 fontWidth):
+        QPainter(pd)
     {
         bRightToLeft = bRTL;
         if(bRTL)
@@ -51,15 +53,16 @@ class RLPainter : public QPainter
 
     void drawText(qint32 x, qint32 y, const QString& s, bool bAdapt = false)
     {
+        qint32 len = SafeInt<qint32>(s.length());
         Qt::LayoutDirection ld = (!bRightToLeft || !bAdapt) ? Qt::LeftToRight : Qt::RightToLeft;
         // Qt will automaticly reverse the text as needed just set the layout direction
         QPainter::setLayoutDirection(ld);
         if(ld == Qt::RightToLeft)
         {
-            QPainter::drawText(m_xOffset - m_fontWidth * s.length() - x, y, s);
+            QPainter::drawText(m_xOffset - m_fontWidth * len - x, y, s);
             return;
         }
-        QPainter::drawText(m_xOffset - m_fontWidth * s.length() + x, y, s);
+        QPainter::drawText(m_xOffset - m_fontWidth * len + x, y, s);
     }
 
     void drawLine(qint32 x1, qint32 y1, qint32 x2, qint32 y2)
