@@ -49,11 +49,8 @@ Optimizations: Skip unneeded steps.
 
 #include <QByteArray>
 #include <QProcess>
-#include <QScopedPointer>
 #include <QString>
 #include <QTemporaryFile>
-#include <QTextCodec>
-#include <QVector>
 
 extern std::unique_ptr<Options> gOptions;
 
@@ -145,7 +142,8 @@ void SourceData::setData(const QString& data)
         m_tempInputFileName = m_tempFile.fileName();
     }
     m_fileAccess = FileAccess(m_tempInputFileName);
-    QByteArray ba = QTextCodec::codecForName("UTF-8")->fromUnicode(data);
+    auto fromString = QStringEncoder(QStringEncoder::Utf8);
+    QByteArray ba = fromString(data);
     bool bSuccess = m_fileAccess.writeFile(ba.constData(), ba.length());
     if(!bSuccess)
     {
@@ -317,8 +315,7 @@ std::optional<const QByteArray> SourceData::detectEncoding(const QString& fileNa
         char buf[400];
 
         qint64 size = f.read(buf, sizeof(buf));
-        FileOffset skipBytes = 0;
-        return detectEncoding(buf, size, skipBytes);
+        return detectEncoding(buf, size);
     }
     return {};
 }
@@ -576,17 +573,16 @@ bool SourceData::FileData::preprocess(const QByteArray& encoding, bool removeCom
     QString line;
     QChar curChar, prevChar = '\0';
     LineType lines = 0;
-    QtSizeType lastOffset = 0;
-    FileOffset skipBytes = 0;
-    QScopedPointer<CommentParser> parser(new DefaultCommentParser());
+    qsizetype lastOffset = 0;
+    std::unique_ptr<CommentParser> parser(new DefaultCommentParser());
 
     // detect line end style
-    QVector<e_LineEndStyle> vOrigDataLineEndStyle;
+    std::vector<e_LineEndStyle> vOrigDataLineEndStyle;
     m_eLineEndStyle = eLineEndStyleUndefined;
 
-    QByteArray pCodec = detectEncoding(m_pBuf.get(), mDataSize, skipBytes).value_or(encoding);
+    QByteArray pCodec = detectEncoding(m_pBuf.get(), mDataSize).value_or(encoding);
 
-    if(mDataSize - skipBytes > limits<qint32>::max())
+    if(mDataSize > limits<qint32>::max())
     {
         reset();
         return false;
@@ -594,19 +590,17 @@ bool SourceData::FileData::preprocess(const QByteArray& encoding, bool removeCom
 
     try
     {
-        const QByteArray ba = QByteArray::fromRawData(m_pBuf.get() + skipBytes, (QtSizeType)(mDataSize - skipBytes));
+        const QByteArray ba = QByteArray::fromRawData(m_pBuf.get(), (qsizetype)(mDataSize));
         EncodedDataStream ds(ba);
 
-        mHasBOM = skipBytes != 0;
         ds.setEncoding(encoding);
-
+        mHasBOM = ds.hasBOM();
         m_bIncompleteConversion = false;
         m_unicodeBuf->clear();
 
         assert(m_unicodeBuf->length() == 0);
 
         mHasEOLTermination = false;
-        bool skipNextRead = false;
         while(!ds.atEnd())
         {
             line.clear();
@@ -616,15 +610,10 @@ bool SourceData::FileData::preprocess(const QByteArray& encoding, bool removeCom
                 return false;
             }
 
-            if(!skipNextRead)
-            {
-                prevChar = curChar;
-                ds.readChar(curChar);
-            }
-            else
-                skipNextRead = false;
+            prevChar = curChar;
+            ds.readChar(curChar);
 
-            QtSizeType firstNonwhite = 0;
+            qsizetype firstNonwhite = 0;
             bool foundNonWhite = false;
 
             while(curChar != '\n' && curChar != '\r')
@@ -660,16 +649,18 @@ bool SourceData::FileData::preprocess(const QByteArray& encoding, bool removeCom
                 case '\r':
                     if((FileOffset)lastOffset < mDataSize)
                     {
-                        prevChar = curChar;
-                        ds.readChar(curChar);
+                        QChar nextChar;
+                        quint64 i = ds.peekChar(nextChar);
+                        if(i == 0)
+                            break;
 
-                        if(curChar == '\n')
+                        if(nextChar == '\n')
                         {
+                            prevChar = curChar;
+                            ds.readChar(curChar);
                             vOrigDataLineEndStyle.push_back(eLineEndStyleDos);
                             break;
                         }
-                        //work around for lack of seek API in QDataStream
-                        skipNextRead = true;
                     }
 
                     //old mac style ending.
@@ -717,7 +708,7 @@ bool SourceData::FileData::preprocess(const QByteArray& encoding, bool removeCom
 
         m_bIsText = true;
 
-        if(!vOrigDataLineEndStyle.isEmpty())
+        if(!vOrigDataLineEndStyle.empty())
             m_eLineEndStyle = vOrigDataLineEndStyle[0];
 
         mLineCount = lines;
@@ -760,11 +751,11 @@ bool SourceData::convertFileEncoding(const QString& fileNameIn, const QByteArray
 
 std::optional<const QByteArray> SourceData::getEncodingFromTag(const QByteArray& s, const QByteArray& encodingTag)
 {
-    QtSizeType encodingPos = s.indexOf(encodingTag);
+    qsizetype encodingPos = s.indexOf(encodingTag);
     if(encodingPos >= 0)
     {
-        QtSizeType apostrophPos = s.indexOf('"', encodingPos + encodingTag.length());
-        QtSizeType apostroph2Pos = s.indexOf('\'', encodingPos + encodingTag.length());
+        qsizetype apostrophPos = s.indexOf('"', encodingPos + encodingTag.length());
+        qsizetype apostroph2Pos = s.indexOf('\'', encodingPos + encodingTag.length());
         char apostroph = '"';
         if(apostroph2Pos >= 0 && (apostrophPos < 0 || apostroph2Pos < apostrophPos))
         {
@@ -772,61 +763,51 @@ std::optional<const QByteArray> SourceData::getEncodingFromTag(const QByteArray&
             apostrophPos = apostroph2Pos;
         }
 
-        QtSizeType encodingEnd = s.indexOf(apostroph, apostrophPos + 1);
+        qsizetype encodingEnd = s.indexOf(apostroph, apostrophPos + 1);
         if(encodingEnd >= 0) // e.g.: <meta charset="utf-8"> or <?xml version="1.0" encoding="ISO-8859-1"?>
         {
             QByteArray encoding = s.mid(apostrophPos + 1, encodingEnd - (apostrophPos + 1));
-            if(QTextCodec::codecForName(encoding))
+            QStringDecoder decoder = QStringDecoder(encoding);
+            if(decoder.isValid())
                 return encoding.toUpper();
         }
         else // e.g.: <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
         {
             QByteArray encoding = s.mid(encodingPos + encodingTag.length(), apostrophPos - (encodingPos + encodingTag.length()));
-            if(QTextCodec::codecForName(encoding))
+            QStringDecoder decoder = QStringDecoder(encoding);
+            if(decoder.isValid())
                 return encoding.toUpper();
         }
     }
     return {};
 }
 
-std::optional<const QByteArray> SourceData::detectEncoding(const char* buf, qint64 size, FileOffset& skipBytes)
+std::optional<const QByteArray> SourceData::detectEncoding(const char* buf, qint64 size)
 {
-    if(size >= 2)
+    std::optional<QStringConverter::Encoding> qtEnum = QStringConverter::encodingForData(buf, size);
+    if(qtEnum.has_value())
     {
-        if(buf[0] == '\xFF' && buf[1] == '\xFE')
-        {
-            skipBytes = 2;
-            return "UTF-16LE";
-        }
+        QByteArray encoding = QByteArray(QStringConverter::nameForEncoding(qtEnum.value())).toUpper();
+        //Only unambigious encodings are returned by QStringConverter::encodingForData this means UTF-8 with BOM.
+        if(encoding == "UTF-8")
+            encoding = "UTF-8-BOM";
 
-        if(buf[0] == '\xFE' && buf[1] == '\xFF')
-        {
-            skipBytes = 2;
-            return "UTF-16BE";
-        }
+        return encoding;
     }
-    if(size >= 3)
-    {
-        if(buf[0] == '\xEF' && buf[1] == '\xBB' && buf[2] == '\xBF')
-        {
-            skipBytes = 3;
-            return "UTF-8-BOM";
-        }
-    }
-    skipBytes = 0;
+
     QByteArray s;
     /*
         We don't need the whole file here just the header.
     */
     if(size <= 5000)
-        s = QByteArray::fromRawData(buf, (QtSizeType)size);
+        s = QByteArray::fromRawData(buf, (qsizetype)size);
     else
         s = QByteArray::fromRawData(buf, 5000);
 
-    QtSizeType xmlHeaderPos = s.indexOf("<?xml");
+    qsizetype xmlHeaderPos = s.indexOf("<?xml");
     if(xmlHeaderPos >= 0)
     {
-        QtSizeType xmlHeaderEnd = s.indexOf("?>", xmlHeaderPos);
+        qsizetype xmlHeaderEnd = s.indexOf("?>", xmlHeaderPos);
         if(xmlHeaderEnd >= 0)
         {
             std::optional<QByteArray> encoding = getEncodingFromTag(s.mid(xmlHeaderPos, xmlHeaderEnd - xmlHeaderPos), "encoding=");
@@ -836,10 +817,10 @@ std::optional<const QByteArray> SourceData::detectEncoding(const char* buf, qint
     }
     else // HTML
     {
-        QtSizeType metaHeaderPos = s.indexOf("<meta");
+        qsizetype metaHeaderPos = s.indexOf("<meta");
         while(metaHeaderPos >= 0)
         {
-            QtSizeType metaHeaderEnd = s.indexOf(">", metaHeaderPos);
+            qsizetype metaHeaderEnd = s.indexOf(">", metaHeaderPos);
             if(metaHeaderEnd >= 0)
             {
                 std::optional<QByteArray> encoding = getEncodingFromTag(s.mid(metaHeaderPos, metaHeaderEnd - metaHeaderPos), "charset=");
@@ -858,13 +839,11 @@ std::optional<const QByteArray> SourceData::detectEncoding(const char* buf, qint
 
 std::optional<const QByteArray> SourceData::detectUTF8(const QByteArray& data)
 {
-    QTextCodec* utf8 = QTextCodec::codecForName("UTF-8");
+    QStringDecoder decoder = QStringDecoder(QStringDecoder::Utf8);
+    QString s = decoder(data);
 
-    QTextCodec::ConverterState state;
-    utf8->toUnicode(data.constData(), SafeInt<qint32>(data.size()), &state);
-
-    if(state.invalidChars == 0)
-        for (qint32 i = 0; i < data.size()-state.remainingChars; i++)
+    if(!decoder.hasError())
+        for (qint32 i = 0; i < data.size(); i++)
             if ((unsigned)data.at(i) > 127)
                 return "UTF-8";
 
