@@ -1,9 +1,11 @@
+// clang-format off
 /*
  KDiff3 - Text Diff And Merge Tool
 
  SPDX-FileCopyrightText: 2020 Michael Reeves reeves.87@gmail.com
  SPDX-License-Identifier: GPL-2.0-or-later
 */
+// clang-format on
 
 #include <QTest>
 #include <QtGlobal>
@@ -25,7 +27,7 @@ class CombinertestTest: public QObject
   private Q_SLOTS:
     void testOrCombiner()
     {
-        boost::signals2::signal<bool(), or> test1;
+        boost::signals2::signal<bool(), or_> test1;
         std::list<boost::signals2::scoped_connection> connections;
 
         connections.push_back(test1.connect(boost::bind(&CombinertestTest::no, this)));
@@ -52,7 +54,7 @@ class CombinertestTest: public QObject
 
     void testAndCombiner()
     {
-        boost::signals2::signal<bool(), and> test1;
+        boost::signals2::signal<bool(), and_> test1;
         std::list<boost::signals2::scoped_connection> connections;
 
         connections.push_back(test1.connect(boost::bind(&CombinertestTest::no, this)));
@@ -82,7 +84,7 @@ class CombinertestTest: public QObject
         boost::signals2::signal<QString (), FirstNonEmpty<QString>> test1;
         std::list<boost::signals2::scoped_connection> connections;
 
-        //Just in case someone moneys with the test functions
+        //Just in case someone monkeys with the test functions
         QVERIFY(emptyString().isEmpty());
         QVERIFY(!nonEmpty1().isEmpty());
         QVERIFY(!nonEmpty1().isEmpty());
