@@ -24,7 +24,6 @@
 #include <QSharedPointer>
 #include <QString>
 #include <QStringList>
-#include <QVector>
 
 class LineData;
 
@@ -160,10 +159,10 @@ class LineData
 {
   private:
     QSharedPointer<QString> mBuffer;
-    QtSizeType mFirstNonWhiteChar = 0;
+    qsizetype mFirstNonWhiteChar = 0;
     //This tracks the offset with-in our unicode buffer not the file offset
-    QtSizeType mOffset = 0;
-    QtSizeType mSize = 0;
+    qsizetype mOffset = 0;
+    qsizetype mSize = 0;
     bool bContainsPureComment = false;
     bool bSkipable = false;//TODO: Move me
 
@@ -175,7 +174,7 @@ class LineData
     LineData& operator=(LineData&&) = default;
 
 
-    inline LineData(const QSharedPointer<QString>& buffer, const QtSizeType inOffset, QtSizeType inSize = 0, QtSizeType inFirstNonWhiteChar = 0, bool inIsSkipable = false, const bool inIsPureComment = false)
+    inline LineData(const QSharedPointer<QString>& buffer, const qsizetype inOffset, qsizetype inSize = 0, qsizetype inFirstNonWhiteChar = 0, bool inIsSkipable = false, const bool inIsPureComment = false)
     {
         mBuffer = buffer;
         mOffset = inOffset;
@@ -184,8 +183,8 @@ class LineData
         bSkipable = inIsSkipable;
         mFirstNonWhiteChar = inFirstNonWhiteChar;
     }
-    [[nodiscard]] inline QtSizeType size() const { return mSize; }
-    [[nodiscard]] inline QtSizeType getFirstNonWhiteChar() const { return mFirstNonWhiteChar; }
+    [[nodiscard]] inline qsizetype size() const { return mSize; }
+    [[nodiscard]] inline qsizetype getFirstNonWhiteChar() const { return mFirstNonWhiteChar; }
 
     /*
         QString::fromRawData allows us to create a light weight QString backed by the buffer memory.
@@ -193,7 +192,7 @@ class LineData
     [[nodiscard]] inline const QString getLine() const { return QString::fromRawData(mBuffer->data() + mOffset, mSize); }
     [[nodiscard]] inline const QSharedPointer<QString>& getBuffer() const { return mBuffer; }
 
-    [[nodiscard]] inline QtSizeType getOffset() const { return mOffset; }
+    [[nodiscard]] inline qsizetype getOffset() const { return mOffset; }
     [[nodiscard]] qint32 width(qint32 tabSize) const; // Calcs width considering tabs.
 
     [[nodiscard]] inline bool whiteLine() const { return mFirstNonWhiteChar == 0; }
@@ -212,7 +211,7 @@ class ManualDiffHelpList; // A list of corresponding ranges
 class Diff3Line;
 class Diff3LineList;
 
-using Diff3LineVector = QVector<Diff3Line*>;
+using Diff3LineVector = std::vector<Diff3Line*>;
 
 class DiffBufferInfo
 {
@@ -476,7 +475,7 @@ struct Diff3WrapLine
     qint32 wrapLineLength = 0;
 };
 
-typedef QVector<Diff3WrapLine> Diff3WrapLineVector;
+typedef std::vector<Diff3WrapLine> Diff3WrapLineVector;
 
 class TotalDiffStatus
 {
