@@ -96,7 +96,7 @@ FileAccess::FileAccess(FileAccess&& b) noexcept:
     m_bExecutable{b.m_bExecutable},
     m_bHidden{b.m_bHidden}
 {
-    mJobHandler.reset(b.mJobHandler.take());
+    mJobHandler.reset(b.mJobHandler.release());
     if(mJobHandler) mJobHandler->setFileAccess(this);
 
     m_url = std::move(b.m_url);
@@ -162,7 +162,7 @@ FileAccess& FileAccess::operator=(FileAccess&& b) noexcept
 {
     if(&b == this) return *this;
 
-    mJobHandler.reset(b.mJobHandler.take());
+    mJobHandler.reset(b.mJobHandler.release());
     if (mJobHandler) mJobHandler->setFileAccess(this);
 
     m_pParent = b.m_pParent;
@@ -250,6 +250,7 @@ void FileAccess::reset()
 
     m_pParent = nullptr;
     m_bValidData = false;
+    setStatusText("");
 }
 
 /*
@@ -420,13 +421,25 @@ void FileAccess::addPath(const QString& txt, bool reinit)
 */
 //This is what KIO uses on windows so we might as well check it.
 #ifdef Q_OS_WIN
+#ifndef S_IRUSR
 #define S_IRUSR 0400  // Read by owner.
+#endif
+#ifndef S_IWUSR
 #define S_IWUSR 0200  // Write by owner.
+#endif
+#ifndef S_IXUSR
 #define S_IXUSR 0100  // Execute by owner.
+#endif
+#ifndef S_IROTH
 #define S_IROTH 00004 // others have read permission
+#endif
+#ifndef S_IWOTH
 #define S_IWOTH 00002 // others have write permission
+#endif
+#ifndef S_IXOTH
 #define S_IXOTH 00001 // others have execute permission
 #endif
+#endif
 void FileAccess::setFromUdsEntry(const KIO::UDSEntry& e, FileAccess* parent)
 {
     long acc = 0;
@@ -775,6 +788,9 @@ bool FileAccess::interruptableReadFile(void* pDestBuffer, qint64 maxLength)
     const qint64 maxChunkSize = 100000;
     qint64 i = 0;
     ProgressProxy::setMaxNofSteps(maxLength / maxChunkSize + 1);
+
+    setStatusText("");
+
     while(i < maxLength)
     {
         qint64 nextLength = std::min(maxLength - i, maxChunkSize);
@@ -796,13 +812,15 @@ bool FileAccess::interruptableReadFile(void* pDestBuffer, qint64 maxLength)
 bool FileAccess::readFile(void* pDestBuffer, qint64 maxLength)
 {
     bool success = false;
+
+    setStatusText("");
     //Avoid hang on linux for special files.
     if(!isNormal())
         return true;
 
     if(isLocal() || !m_localCopy.isEmpty())
     {
-        if(open(QIODevice::ReadOnly))//krazy:exclude=syscalls
+        if(open(QIODevice::ReadOnly))
         {
             success = interruptableReadFile(pDestBuffer, maxLength); // maxLength == f.read( (char*)pDestBuffer, maxLength )
             close();
@@ -821,6 +839,8 @@ bool FileAccess::readFile(void* pDestBuffer, qint64 maxLength)
 bool FileAccess::writeFile(const void* pSrcBuffer, qint64 length)
 {
     ProgressScope pp;
+
+    setStatusText("");
     if(isLocal())
     {
         if(realFile->open(QIODevice::WriteOnly))
@@ -918,6 +938,9 @@ const QString& FileAccess::errorString() const
 bool FileAccess::open(const QFile::OpenMode flags)
 {
     bool result;
+
+    setStatusText("");
+
     result = createLocalCopy();
     if(!result)
     {
@@ -942,10 +965,11 @@ bool FileAccess::open(const QFile::OpenMode flags)
 
 qint64 FileAccess::read(char* data, const qint64 maxlen)
 {
+    setStatusText("");
+
     if(!isNormal())
     {
         //This is not an error special files should be skipped
-        setStatusText(QString());
         return 0;
     }
 
@@ -1082,6 +1106,8 @@ QString FileAccess::cleanPath(const QString& path) // static
 
 bool FileAccess::createBackup(const QString& bakExtension)
 {
+    setStatusText("");
+
     if(exists())
     {
         // First rename the existing file to the bak-file. If a bak-file file exists, delete that.
