@@ -28,7 +28,6 @@
 #include <QCommandLineOption>
 #include <QCommandLineParser>
 #include <QFile>
-#include <QScopedPointer>
 #include <QStandardPaths>
 #include <QStringList>
 #include <QTextStream>
@@ -46,7 +45,7 @@ void initialiseCmdLineArgs(QCommandLineParser* cmdLineParser)
             const QString line = ts.readLine();
             if(line.startsWith(u8"IgnorableCmdLineOptions="))
             {
-                const QtSizeType pos = line.indexOf('=');
+                const qsizetype pos = line.indexOf('=');
                 if(pos >= 0)
                 {
                     ignorableOptionsLine = line.mid(pos + 1);
@@ -77,10 +76,8 @@ void initialiseCmdLineArgs(QCommandLineParser* cmdLineParser)
 
 qint32 main(qint32 argc, char* argv[])
 {
-    constexpr QLatin1String appName("kdiff3", sizeof("kdiff3") - 1);
+    constexpr QLatin1String appName("kdiff3");
     //Syncronize qt HDPI behavoir on all versions/platforms
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
     QGuiApplication::setHighDpiScaleFactorRoundingPolicy(Qt::HighDpiScaleFactorRoundingPolicy::PassThrough);
 
     QApplication app(argc, argv); // KAboutData and QCommandLineParser depend on this being setup.
@@ -94,7 +91,7 @@ qint32 main(qint32 argc, char* argv[])
     appVersion += i18nc("Program version info.", " (64 bit)");
 
     const QString description = i18n("Tool for Comparison and Merge of Files and Folders");
-    const QString copyright = i18n("(c) 2002-2014 Joachim Eibl, (c) 2017 Michael Reeves KF5/Qt5 port");
+    const QString copyright = i18n(u8"©2002-2014 Joachim Eibl, ©2017 Michael Reeves KF5/Qt5 port");
     const QString homePage = QStringLiteral("https://apps.kde.org/kdiff3");
 
     KAboutData aboutData(appName, i18nName,
