@@ -1,3 +1,4 @@
+// clang-format off
 /*
  * KDiff3 - Text Diff And Merge Tool
  *
@@ -11,6 +12,8 @@
 #define OPTIONS_H
 
 #include "combiners.h"
+#include "RecentItems.h"
+#include "TypeUtils.h"
 
 #include <boost/signals2.hpp>
 #include <list>
@@ -35,6 +38,7 @@ enum e_LineEndStyle
 {
     eLineEndStyleUnix = 0,
     eLineEndStyleDos,
+    eLineEndStyleOldMac,
     eLineEndStyleAutoDetect,
     eLineEndStyleUndefined, // only one line exists
     eLineEndStyleConflict   // User must resolve manually
@@ -67,13 +71,10 @@ class Options
     [[nodiscard]] bool isFullScreen() const { return m_bFullScreen; };
     void setFullScreen(const bool fullScreen) { m_bFullScreen = fullScreen; };
 
-    [[nodiscard]] bool isMaximised() const { return m_bMaximised; };
-    void setMaximised(const bool maximised) { m_bMaximised = maximised; };
+    [[nodiscard]] bool isMaximized() const { return m_bMaximized; };
+    void setMaximized(const bool maximized) { m_bMaximized = maximized; };
 
-    [[nodiscard]] bool isToolBarVisable() const { return m_bShowToolBar; }
-    void setToolbarState(bool inShown) { m_bShowToolBar = inShown; }
-
-    [[nodiscard]] bool isStatusBarVisable() const { return m_bShowStatusBar; }
+    [[nodiscard]] bool isStatusBarVisible() const { return m_bShowStatusBar; }
     void setStatusBarState(bool inShown) { m_bShowStatusBar = inShown; }
 
     [[nodiscard]] inline const QFont& defaultFont() { return mFont; };
@@ -82,11 +83,15 @@ class Options
     [[nodiscard]] bool wordWrapOn() const { return m_bWordWrap; }
     void setWordWrap(const bool enabled) { m_bWordWrap = enabled; }
 
+    [[nodiscard]] bool replaceTabs() const { return m_bReplaceTabs; }
+    [[nodiscard]] bool autoIndent() const { return m_bAutoIndentation; }
+    [[nodiscard]] qint32 tabSize() const { return m_tabSize; }
+
     [[nodiscard]] bool ignoreComments() const { return m_bIgnoreComments; }
 
     [[nodiscard]] bool whiteSpaceIsEqual() const { return m_bDmWhiteSpaceEqual; }
 
-    [[nodiscard]] const QColor& forgroundColor() const { return m_fgColor; };
+    [[nodiscard]] const QColor& foregroundColor() const { return m_fgColor; };
     [[nodiscard]] const QColor& backgroundColor() const
     {
         if(mPrintMode) return mPrintBackground;
@@ -99,9 +104,23 @@ class Options
 
     [[nodiscard]] const QColor& conflictColor() const { return m_colorForConflict; }
 
+    [[nodiscard]] RecentItems<maxNofRecentFiles>& getRecentFilesA() { return m_recentAFiles; }
+    [[nodiscard]] RecentItems<maxNofRecentFiles>& getRecentFilesB() { return m_recentBFiles; }
+    [[nodiscard]] RecentItems<maxNofRecentFiles>& getRecentFilesC() { return m_recentCFiles; }
+
+    [[nodiscard]] RecentItems<maxNofRecentFiles>& getRecentOutputFiles() { return m_recentOutputFiles; }
+
     inline void beginPrint() { mPrintMode = true; }
     inline void endPrint() { mPrintMode = false; }
 
+    [[nodiscard]] inline const QColor& getCurrentRangeBgColor() const { return m_currentRangeBgColor; };
+    [[nodiscard]] inline const QColor& getCurrentRangeDiffBgColor() const { return m_currentRangeDiffBgColor; };
+    [[nodiscard]] inline const QColor& oldestFileColor() const { return m_oldestFileColor; }
+    [[nodiscard]] inline const QColor& midAgeFileColor() const { return m_midAgeFileColor; }
+    [[nodiscard]] inline const QColor& newestFileColor() const { return m_newestFileColor; }
+    [[nodiscard]] inline const QColor& missingFileColor() const { return m_missingFileColor; }
+    [[nodiscard]] inline const QColor& manualHelpRangeColor() const { return m_manualHelpRangeColor; }
+
   private:
     void addOptionItem(std::shared_ptr<OptionItemBase> inItem);
 
@@ -112,13 +131,14 @@ class Options
 
     const QColor mPrintBackground = Qt::white;
 
+    // clang-format off
     // Some settings that are not available in the option dialog:
     QSize  m_geometry = QSize(600, 400);
     QPoint m_position = QPoint(0, 22);
     bool   m_bFullScreen = false;
-    bool   m_bMaximised = false;
-    bool   m_bShowToolBar = true;
+    bool   m_bMaximized = false;
     bool   m_bShowStatusBar = true;
+    // clang-format on
 
     // These are the results of the option dialog.
     QFont mFont;
@@ -134,9 +154,9 @@ class Options
     QColor m_colorC;
     QColor m_colorForConflict = Qt::red;
 
-  public:
     QColor m_currentRangeBgColor;
     QColor m_currentRangeDiffBgColor;
+
     QColor m_oldestFileColor = qRgb(0xf0, 0, 0);
     QColor m_midAgeFileColor = qRgb(0xc0, 0xc0, 0);
     QColor m_newestFileColor = qRgb(0, 0xd0, 0);
@@ -144,21 +164,22 @@ class Options
     QColor m_manualHelpRangeColor = qRgb(0xff, 0xd0, 0x80);
 
     bool m_bWordWrap = false;
-
     bool m_bReplaceTabs = false;
     bool m_bAutoIndentation = true;
-    int  m_tabSize = 8;
+    qint32 m_tabSize = 8;
+
+  public:
     bool m_bAutoCopySelection = false;
     bool m_bSameEncoding = true;
-    QTextCodec* m_pEncodingA = nullptr;
-    bool m_bAutoDetectUnicodeA = true;
-    QTextCodec* m_pEncodingB = nullptr;
-    bool m_bAutoDetectUnicodeB = true;
-    QTextCodec* m_pEncodingC = nullptr;
-    bool m_bAutoDetectUnicodeC = true;
-    QTextCodec* m_pEncodingOut = nullptr;
+    QByteArray mEncodingA = nullptr;
+    bool mAutoDetectA = true;
+    QByteArray mEncodingB = nullptr;
+    bool mAutoDetectB = true;
+    QByteArray mEncodingC = nullptr;
+    bool mAutoDetectC = true;
+    QByteArray mEncodingOut = nullptr;
     bool m_bAutoSelectOutEncoding = true;
-    QTextCodec* m_pEncodingPP = nullptr;
+    QByteArray mEncodingPP = nullptr;
     e_LineEndStyle m_lineEndStyle = eLineEndStyleAutoDetect;
 
     bool m_bTryHard = true;
@@ -169,8 +190,8 @@ class Options
     bool m_bShowInfoDialogs = true;
     bool m_bDiff3AlignBC = false;
 
-    int  m_whiteSpace2FileMergeDefault = 0;
-    int  m_whiteSpace3FileMergeDefault = 0;
+    qint32  m_whiteSpace2FileMergeDefault = 0;
+    qint32  m_whiteSpace3FileMergeDefault = 0;
     bool m_bIgnoreCase = false;
     bool m_bIgnoreNumbers = false;
     bool m_bIgnoreComments = false;
@@ -183,20 +204,20 @@ class Options
     QString m_historyEntryStartRegExp;
     bool m_bHistoryMergeSorting = false;
     QString m_historyEntryStartSortKeyOrder = "4,3,2,5,1,6";
-    int m_maxNofHistoryEntries = -1;
+    qint32 m_maxNofHistoryEntries = -1;
     QString m_IrrelevantMergeCmd;
     bool m_bAutoSaveAndQuitOnMergeWithoutConflicts = false;
 
     bool m_bAutoAdvance = false;
-    int  m_autoAdvanceDelay = 500;
+    qint32  m_autoAdvanceDelay = 500;
 
-    QStringList m_recentAFiles;
-    QStringList m_recentBFiles;
-    QStringList m_recentCFiles;
+    RecentItems<maxNofRecentFiles> m_recentAFiles;
+    RecentItems<maxNofRecentFiles> m_recentBFiles;
+    RecentItems<maxNofRecentFiles> m_recentCFiles;
 
-    QStringList m_recentEncodings;
+    RecentItems<maxNofRecentCodecs> m_recentEncodings;
 
-    QStringList m_recentOutputFiles;
+    RecentItems<maxNofRecentFiles> m_recentOutputFiles;
 
     // Directory Merge options
     bool m_bDmSyncMode = false;
